@@ -10,7 +10,7 @@ from web_foundation.workers.io.http.chaining import InputContext
 
 
 async def exec_access(inc: InputContext,
-                      model: AbstractDbModel,
+                      model: Type[AbstractDbModel],
                       fetch_fields: List[str] = None,
                       middleware: Type[AccessDMW] = AccessDMW
                       ):
