@@ -12,8 +12,7 @@ from pydantic import BaseSettings
 from web_foundation.kernel.dispatcher import IDispatcher
 from web_foundation.app.resources.cache.repo import AppStore
 from web_foundation.app.resources.cache.memory import InMemoryDictStore
-from web_foundation.app.service import Service
-from web_foundation.kernel.logger import setup_loggers, LoggerSettings
+from web_foundation.app.services.service import Service
 from web_foundation.workers.worker import GenWorker
 
 AppConfig = TypeVar("AppConfig", bound=BaseSettings)
