@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import List, Type
+from typing import List, Type, Callable
 
 from pydantic import BaseModel
 from sanic import Sanic
@@ -28,6 +28,7 @@ class RouteConf:
 
 
 class ExtRouter(Router):
+    chaining: Callable
     chains: List[RouteConf]
 
     def apply_routes(self, app: Sanic, *args, **kwargs):
