@@ -51,10 +51,12 @@ class RtConnection(Generic[GenericIMessage]):
     _on_disconnect: Callable[[], Coroutine]
 
     def __init__(self, input_ctx: InputContext, writeable: WriteableObj,
-                 resolve_callback: RtEventCallback = None,
+                 resolve_callback: RtEventCallback,
                  debug: bool = False, ping_enable: bool = False,
                  ping_timeout=None,
                  listen_timeout=None):
+        if not resolve_callback:
+            raise AttributeError("Resolve Callback can't bee none")
         self.writeable = writeable
         self.resolve_callback = resolve_callback
         self.input_ctx = input_ctx
@@ -80,12 +82,11 @@ class RtConnection(Generic[GenericIMessage]):
         await self._ping()
 
     async def send_after_call(self, event: GenericIMessage):
-        if self.resolve_callback:
-            msg = await self.resolve_callback(self, event)
-            if msg:
-                self._last_event_id += 1
-                msg.event_id = self._last_event_id
-                await self.writeable.write(msg.to_sent)
+        msg = await self.resolve_callback(self, event)
+        if msg:
+            self._last_event_id += 1
+            msg.event_id = self._last_event_id
+            await self.writeable.write(msg.to_sent)
 
     async def __aenter__(self):
         pass
