@@ -97,11 +97,10 @@ class HttpServer(Worker):
         sock.set_inheritable(True)
         return sock
 
-    async def on_rt_event(self, message: GenericIMessage, resolve_callback: RtEventCallback = None):
+    async def broadcasts_rt(self, message: GenericIMessage):
         promises = []
         for conn in self.rt_connections:
-            if conn.resolve_callback.__name__ == resolve_callback.__name__:
-                promises.append(conn.send_after_call(message))
+            promises.append(conn.send_after_call(message))
         await asyncio.gather(*promises)
 
     async def accept_rt_connection(self, conn: RtConnection,
@@ -150,10 +149,8 @@ def create_io_workers(server_cls: Type[HttpServer],
     return workers
 
 
-def subscribe_worker_rt_callback(*workers: HttpServer,
-                                 event_type: List[Type[IMessage] | str] | Type[IMessage] | str,
-                                 callback: RtEventCallback,
-                                 use_nested_classes: bool = False):
+def create_rt_subscribes(*workers: HttpServer,
+                         event_type: List[Type[IMessage] | str] | Type[IMessage] | str,
+                         **kwargs, ):
     for worker in workers:
-        worker.channel.add_event_listener(event_type, partial(worker.on_rt_event, resolve_callback=callback),
-                                          use_nested_classes=use_nested_classes)
+        worker.channel.add_event_listener(event_type, worker.broadcasts_rt, **kwargs)
